@@ -6,17 +6,28 @@ EXTENSIONS = {
     'asciidoc': {'text', 'asciidoc'},
     'apinotes': {'text', 'apinotes'},
     'asar': {'binary', 'asar'},
+    'asm': {'text', 'asm'},
+    'astro': {'text', 'astro'},
     'avif': {'binary', 'image', 'avif'},
+    'avsc': {'text', 'avro-schema'},
     'bash': {'text', 'shell', 'bash'},
     'bat': {'text', 'batch'},
     'bats': {'text', 'shell', 'bash', 'bats'},
+    'bazel': {'text', 'bazel'},
+    'bb': {'text', 'bitbake'},
+    'bbappend': {'text', 'bitbake'},
+    'bbclass': {'text', 'bitbake'},
     'beancount': {'text', 'beancount'},
     'bib': {'text', 'bib'},
     'bmp': {'binary', 'image', 'bitmap'},
     'bz2': {'binary', 'bzip2'},
+    'bz3': {'binary', 'bzip3'},
     'bzl': {'text', 'bazel'},
     'c': {'text', 'c'},
+    'c++': {'text', 'c++'},
+    'c++m': {'text', 'c++'},
     'cc': {'text', 'c++'},
+    'ccm': {'text', 'c++'},
     'cfg': {'text'},
     'chs': {'text', 'c2hs'},
     'cjs': {'text', 'javascript'},
@@ -28,6 +39,7 @@ EXTENSIONS = {
     'coffee': {'text', 'coffee'},
     'conf': {'text'},
     'cpp': {'text', 'c++'},
+    'cppm': {'text', 'c++'},
     'cr': {'text', 'crystal'},
     'crt': {'text', 'pem'},
     'cs': {'text', 'c#'},
@@ -36,10 +48,12 @@ EXTENSIONS = {
     'cson': {'text', 'cson'},
     'css': {'text', 'css'},
     'csv': {'text', 'csv'},
+    'csx': {'text', 'c#', 'c#script'},
     'cu': {'text', 'cuda'},
     'cue': {'text', 'cue'},
     'cuh': {'text', 'cuda'},
     'cxx': {'text', 'c++'},
+    'cxxm': {'text', 'c++'},
     'cylc': {'text', 'cylc'},
     'dart': {'text', 'dart'},
     'dbc': {'text', 'dbc'},
@@ -49,6 +63,8 @@ EXTENSIONS = {
     'ear': {'binary', 'zip', 'jar'},
     'edn': {'text', 'clojure', 'edn'},
     'ejs': {'text', 'ejs'},
+    'ejson': {'text', 'json', 'ejson'},
+    'elm': {'text', 'elm'},
     'env': {'text', 'dotenv'},
     'eot': {'binary', 'eot'},
     'eps': {'binary', 'eps'},
@@ -65,10 +81,14 @@ EXTENSIONS = {
     'feature': {'text', 'gherkin'},
     'fish': {'text', 'fish'},
     'fits': {'binary', 'fits'},
+    'fs': {'text', 'f#'},
+    'fsx': {'text', 'f#', 'f#script'},
     'gd': {'text', 'gdscript'},
     'gemspec': {'text', 'ruby'},
     'geojson': {'text', 'geojson', 'json'},
+    'ggb': {'binary', 'zip', 'ggb'},
     'gif': {'binary', 'image', 'gif'},
+    'gleam': {'text', 'gleam'},
     'go': {'text', 'go'},
     'gotmpl': {'text', 'gotmpl'},
     'gpx': {'text', 'gpx', 'xml'},
@@ -100,6 +120,7 @@ EXTENSIONS = {
     'ino': {'text', 'ino', 'c++'},
     'inx': {'text', 'xml', 'inx'},
     'ipynb': {'text', 'jupyter', 'json'},
+    'ixx': {'text', 'c++'},
     'j2': {'text', 'jinja'},
     'jade': {'text', 'jade'},
     'jar': {'binary', 'zip', 'jar'},
@@ -142,6 +163,7 @@ EXTENSIONS = {
     'md': {'text', 'markdown'},
     'mdx': {'text', 'mdx'},
     'meson': {'text', 'meson'},
+    'metal': {'text', 'metal'},
     'mib': {'text', 'mib'},
     'mjs': {'text', 'javascript'},
     'mk': {'text', 'makefile'},
@@ -180,6 +202,8 @@ EXTENSIONS = {
     'properties': {'text', 'java-properties'},
     'proto': {'text', 'proto'},
     'ps1': {'text', 'powershell'},
+    'psd1': {'text', 'powershell'},
+    'psm1': {'text', 'powershell'},
     'pug': {'text', 'pug'},
     'puml': {'text', 'plantuml'},
     'purs': {'text', 'purescript'},
@@ -188,6 +212,7 @@ EXTENSIONS = {
     'py': {'text', 'python'},
     'pyi': {'text', 'pyi'},
     'pyproj': {'text', 'xml', 'pyproj'},
+    'pyt': {'text', 'python'},
     'pyx': {'text', 'cython'},
     'pyz': {'binary', 'pyz'},
     'pyzw': {'binary', 'pyz'},
@@ -240,6 +265,7 @@ EXTENSIONS = {
     'twig': {'text', 'twig'},
     'txsprofile': {'text', 'ini', 'txsprofile'},
     'txt': {'text', 'plain-text'},
+    'txtpb': {'text', 'textproto'},
     'urdf': {'text', 'xml', 'urdf'},
     'v': {'text', 'verilog'},
     'vb': {'text', 'vb'},
@@ -260,6 +286,8 @@ EXTENSIONS = {
     'woff2': {'binary', 'woff2'},
     'wsgi': {'text', 'wsgi', 'python'},
     'xhtml': {'text', 'xml', 'html', 'xhtml'},
+    'xacro': {'text', 'xml', 'urdf', 'xacro'},
+    'xctestplan': {'text', 'json'},
     'xml': {'text', 'xml'},
     'xq': {'text', 'xquery'},
     'xql': {'text', 'xquery'},
@@ -302,6 +330,7 @@ NAMES = {
     '.csslintrc': EXTENSIONS['json'] | {'csslintrc'},
     '.dockerignore': {'text', 'dockerignore'},
     '.editorconfig': {'text', 'editorconfig'},
+    '.envrc': EXTENSIONS['bash'],
     '.flake8': EXTENSIONS['ini'] | {'flake8'},
     '.gitattributes': {'text', 'gitattributes'},
     '.gitconfig': EXTENSIONS['ini'] | {'gitconfig'},
@@ -318,6 +347,7 @@ NAMES = {
     '.prettierignore': {'text', 'gitignore', 'prettierignore'},
     '.pypirc': EXTENSIONS['ini'] | {'pypirc'},
     '.rstcheck.cfg': EXTENSIONS['ini'],
+    '.salt-lint': EXTENSIONS['yaml'] | {'salt-lint'},
     '.yamllint': EXTENSIONS['yaml'] | {'yamllint'},
     '.zlogin': EXTENSIONS['zsh'],
     '.zlogout': EXTENSIONS['zsh'],
@@ -325,14 +355,20 @@ NAMES = {
     '.zshrc': EXTENSIONS['zsh'],
     '.zshenv': EXTENSIONS['zsh'],
     'AUTHORS': EXTENSIONS['txt'],
+    'bblayers.conf': EXTENSIONS['bb'],
+    'bitbake.conf': EXTENSIONS['bb'],
     'BUILD': EXTENSIONS['bzl'],
-    'BUILD.bazel': EXTENSIONS['bzl'],
+    'Cargo.toml': EXTENSIONS['toml'] | {'cargo'},
+    'Cargo.lock': EXTENSIONS['toml'] | {'cargo-lock'},
     'CMakeLists.txt': EXTENSIONS['cmake'],
     'CHANGELOG': EXTENSIONS['txt'],
     'config.ru': EXTENSIONS['rb'],
+    'Containerfile': {'text', 'dockerfile'},
     'CONTRIBUTING': EXTENSIONS['txt'],
+    'copy.bara.sky': EXTENSIONS['bzl'],
     'COPYING': EXTENSIONS['txt'],
     'Dockerfile': {'text', 'dockerfile'},
+    'direnvrc': EXTENSIONS['bash'],
     'Gemfile': EXTENSIONS['rb'],
     'Gemfile.lock': {'text'},
     'GNUmakefile': EXTENSIONS['mk'],
@@ -360,6 +396,8 @@ NAMES = {
     'setup.cfg': EXTENSIONS['ini'],
     'sys.config': EXTENSIONS['erl'],
     'sys.config.src': EXTENSIONS['erl'],
+    'Tiltfile': {'text', 'tiltfile'},
+    'Vagrantfile': EXTENSIONS['rb'],
     'WORKSPACE': EXTENSIONS['bzl'],
     'wscript': EXTENSIONS['py'],
 }
